==> scalarx_2.10-0.2.1-JS.jar: rx/ops/0003-Debounce.js <==
/** @constructor */
ScalaJS.c.rx_ops_Debounce = (function() {
  ScalaJS.c.rx_core_Dynamic.call(this);
  this.source$2 = null;
  this.interval$2 = null;
  this.scheduler$2 = null;
  this.ex$2 = null;
  this.nextPingTime$2 = null
});
ScalaJS.c.rx_ops_Debounce.prototype = new ScalaJS.inheritable.rx_core_Dynamic();
ScalaJS.c.rx_ops_Debounce.prototype.constructor = ScalaJS.c.rx_ops_Debounce;
ScalaJS.c.rx_ops_Debounce.prototype.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference = (function() {
  return this.nextPingTime$2
});
ScalaJS.c.rx_ops_Debounce.prototype.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set = (function(incoming, evidence$1) {
  var npt = ScalaJS.as.scala_concurrent_duration_Deadline(this.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference().get__O());
  if ((ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline().$$greater__O__Z(npt) && this.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference().compareAndSet__O__O__Z(npt, ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline().$$plus__Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_Deadline(this.interval$2)))) {
    return ScalaJS.c.rx_core_Dynamic.prototype.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set.call(this, incoming, evidence$1)
  } else {
    this.scheduler$2.scheduleOnce__Lscala_concurrent_duration_FiniteDuration__Lscala_Function0__Lscala_concurrent_ExecutionContext__V(npt.$$minus__Lscala_concurrent_duration_Deadline__Lscala_concurrent_duration_FiniteDuration(ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline()), new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction0((function(arg$outer, incoming$1, evidence$1$1, npt$1) {
      return (function() {
        if (arg$outer.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference().compareAndSet__O__O__Z(npt$1, ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline())) {
          if ((!ScalaJS.anyRefEqEq(arg$outer.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set(incoming$1, evidence$1$1), ScalaJS.modules.scala_collection_immutable_Nil()))) {
            return arg$outer.propagate__Lrx_core_Propagator__O(evidence$1$1)
          } else {
            return ScalaJS.modules.scala_runtime_BoxedUnit().UNIT__Lscala_runtime_BoxedUnit()
          }
        } else {
          return ScalaJS.modules.scala_runtime_BoxedUnit().UNIT__Lscala_runtime_BoxedUnit()
        }
      })
    })(this, incoming, evidence$1, npt)), this.ex$2);
    return ScalaJS.modules.scala_Predef().Set__Lscala_collection_immutable_Set$().empty__Lscala_collection_immutable_Set()
  }
});
ScalaJS.c.rx_ops_Debounce.prototype.level__J = (function() {
  return this.source$2.level__J().$$plus__Lscala_scalajs_runtime_Long__Lscala_scalajs_runtime_Long(ScalaJS.modules.scala_scalajs_runtime_Long().fromInt__I__Lscala_scalajs_runtime_Long(1))
});
ScalaJS.c.rx_ops_Debounce.prototype.init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext = (function(source, interval, scheduler, ex) {
  this.source$2 = source;
  this.interval$2 = interval;
  this.scheduler$2 = scheduler;
  this.ex$2 = ex;
  ScalaJS.c.rx_core_Dynamic.prototype.init___Lscala_Function0__T.call(this, new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction0((function(source$1) {
    return (function() {
      return source$1.apply__O()
    })
  })(source)), ("Debounced " + source.name__T()));
  this.nextPingTime$2 = new ScalaJS.c.java_util_concurrent_atomic_AtomicReference().init___O(ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline());
  return this
});
ScalaJS.c.rx_ops_Debounce.prototype.nextPingTime = (function() {
  return this.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference()
});
ScalaJS.c.rx_ops_Debounce.prototype.nextPingTime__ = (function() {
  return this.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference()
});
/** @constructor */
ScalaJS.inheritable.rx_ops_Debounce = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_Debounce.prototype = ScalaJS.c.rx_ops_Debounce.prototype;
/** @constructor */
ScalaJS.classes.rx_ops_Debounce = (function(arg$1, arg$2, arg$3, arg$4) {
  ScalaJS.c.rx_ops_Debounce.call(this);
  return this.init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext(arg$1, arg$2, arg$3, arg$4)
});
ScalaJS.classes.rx_ops_Debounce.prototype = ScalaJS.c.rx_ops_Debounce.prototype;
ScalaJS.is.rx_ops_Debounce = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_Debounce)))
});
ScalaJS.as.rx_ops_Debounce = (function(obj) {
  if ((ScalaJS.is.rx_ops_Debounce(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.Debounce")
  }
});
ScalaJS.isArrayOf.rx_ops_Debounce = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_Debounce)))
});
ScalaJS.asArrayOf.rx_ops_Debounce = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_Debounce(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.Debounce;", depth)
  }
});
ScalaJS.data.rx_ops_Debounce = new ScalaJS.ClassTypeData({
  rx_ops_Debounce: 0
}, false, "rx.ops.Debounce", ScalaJS.data.rx_core_Dynamic, {
  rx_ops_Debounce: 1,
  rx_core_Dynamic: 1,
  rx_ops_Spinlock: 1,
  rx_ops_Incrementing: 1,
  rx_core_Rx: 1,
  rx_core_Reactor: 1,
  rx_core_Emitter: 1,
  rx_core_Node: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_Debounce.prototype.$classData = ScalaJS.data.rx_ops_Debounce;
//@ sourceMappingURL=0003-Debounce.js.map

==> scalarx_2.10-0.2.2-JS.jar: rx/ops/0003-Debounce.js <==
/** @constructor */
ScalaJS.c.rx_ops_Debounce = (function() {
  ScalaJS.c.rx_core_Dynamic.call(this);
  this.source$2 = null;
  this.interval$2 = null;
  this.scheduler$2 = null;
  this.ex$2 = null;
  this.nextPingTime$2 = null
});
ScalaJS.c.rx_ops_Debounce.prototype = new ScalaJS.inheritable.rx_core_Dynamic();
ScalaJS.c.rx_ops_Debounce.prototype.constructor = ScalaJS.c.rx_ops_Debounce;
ScalaJS.c.rx_ops_Debounce.prototype.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference = (function() {
  return this.nextPingTime$2
});
ScalaJS.c.rx_ops_Debounce.prototype.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set = (function(incoming, evidence$1) {
  var npt = ScalaJS.as.scala_concurrent_duration_Deadline(this.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference().get__O());
  if ((ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline().$$greater__O__Z(npt) && this.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference().compareAndSet__O__O__Z(npt, ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline().$$plus__Lscala_concurrent_duration_FiniteDuration__Lscala_concurrent_duration_Deadline(this.interval$2)))) {
    return ScalaJS.c.rx_core_Dynamic.prototype.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set.call(this, incoming, evidence$1)
  } else {
    this.scheduler$2.scheduleOnce__Lscala_concurrent_duration_FiniteDuration__Lscala_Function0__Lscala_concurrent_ExecutionContext__V(npt.$$minus__Lscala_concurrent_duration_Deadline__Lscala_concurrent_duration_FiniteDuration(ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline()), new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction0((function(arg$outer, incoming$1, evidence$1$1, npt$1) {
      return (function() {
        if (arg$outer.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference().compareAndSet__O__O__Z(npt$1, ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline())) {
          if ((!ScalaJS.anyRefEqEq(arg$outer.ping__Lscala_collection_immutable_Set__Lrx_core_Propagator__Lscala_collection_immutable_Set(incoming$1, evidence$1$1), ScalaJS.modules.scala_collection_immutable_Nil()))) {
            return arg$outer.propagate__Lrx_core_Propagator__O(evidence$1$1)
          } else {
            return ScalaJS.modules.scala_runtime_BoxedUnit().UNIT__Lscala_runtime_BoxedUnit()
          }
        } else {
          return ScalaJS.modules.scala_runtime_BoxedUnit().UNIT__Lscala_runtime_BoxedUnit()
        }
      })
    })(this, incoming, evidence$1, npt)), this.ex$2);
    return ScalaJS.modules.scala_Predef().Set__Lscala_collection_immutable_Set$().empty__Lscala_collection_immutable_Set()
  }
});
ScalaJS.c.rx_ops_Debounce.prototype.level__J = (function() {
  return this.source$2.level__J().$$plus__Lscala_scalajs_runtime_Long__Lscala_scalajs_runtime_Long(ScalaJS.modules.scala_scalajs_runtime_Long().fromInt__I__Lscala_scalajs_runtime_Long(1))
});
ScalaJS.c.rx_ops_Debounce.prototype.init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext = (function(source, interval, scheduler, ex) {
  this.source$2 = source;
  this.interval$2 = interval;
  this.scheduler$2 = scheduler;
  this.ex$2 = ex;
  ScalaJS.c.rx_core_Dynamic.prototype.init___Lscala_Function0__T.call(this, new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction0((function(source$1) {
    return (function() {
      return source$1.apply__O()
    })
  })(source)), ("Debounced " + source.name__T()));
  this.nextPingTime$2 = new ScalaJS.c.java_util_concurrent_atomic_AtomicReference().init___O(ScalaJS.modules.scala_concurrent_duration_Deadline().now__Lscala_concurrent_duration_Deadline());
  return this
});
ScalaJS.c.rx_ops_Debounce.prototype.nextPingTime = (function() {
  return this.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference()
});
ScalaJS.c.rx_ops_Debounce.prototype.nextPingTime__ = (function() {
  return this.nextPingTime__Ljava_util_concurrent_atomic_AtomicReference()
});
/** @constructor */
ScalaJS.inheritable.rx_ops_Debounce = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_Debounce.prototype = ScalaJS.c.rx_ops_Debounce.prototype;
/** @constructor */
ScalaJS.classes.rx_ops_Debounce = (function(arg$1, arg$2, arg$3, arg$4) {
  ScalaJS.c.rx_ops_Debounce.call(this);
  return this.init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext(arg$1, arg$2, arg$3, arg$4)
});
ScalaJS.classes.rx_ops_Debounce.prototype = ScalaJS.c.rx_ops_Debounce.prototype;
ScalaJS.is.rx_ops_Debounce = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_Debounce)))
});
ScalaJS.as.rx_ops_Debounce = (function(obj) {
  if ((ScalaJS.is.rx_ops_Debounce(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.Debounce")
  }
});
ScalaJS.isArrayOf.rx_ops_Debounce = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_Debounce)))
});
ScalaJS.asArrayOf.rx_ops_Debounce = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_Debounce(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.Debounce;", depth)
  }
});
ScalaJS.data.rx_ops_Debounce = new ScalaJS.ClassTypeData({
  rx_ops_Debounce: 0
}, false, "rx.ops.Debounce", ScalaJS.data.rx_core_Dynamic, {
  rx_ops_Debounce: 1,
  rx_core_Dynamic: 1,
  rx_core_Spinlock: 1,
  rx_core_Incrementing: 1,
  rx_core_Rx: 1,
  rx_core_Reactor: 1,
  rx_core_Emitter: 1,
  rx_core_Node: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_Debounce.prototype.$classData = ScalaJS.data.rx_ops_Debounce;
//@ sourceMappingURL=0003-Debounce.js.map
